.. _swh-loader-git:

Software Heritage - Git loader
==============================

Loader for `Git <https://git-scm.com/>`_ repositories.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
